# Autogenerated by Astropy-affiliated package astropy_helpers's setup.py on 2015-03-07 13:02:20.399360
from __future__ import unicode_literals
import datetime

version = "1.0.1"
githash = "483a89fe8d8bbacd52e5831e3897680ff9e23966"


major = 1
minor = 0
bugfix = 1

release = True
timestamp = datetime.datetime(2015, 3, 7, 13, 2, 20, 399360)
debug = False

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"
